@@ -10,11 +10,13 @@ public_api = [
     'Message',
     'device',
     'proxy',
+    'proxy_steerable',
     'zmq_poll',
     'strerror',
     'zmq_errno',
     'has',
     'curve_keypair',
+    'curve_public',
     'constants',
     'zmq_version_info',
     'IPC_PATH_MAX_LEN',
